Crate blitz_paint

Crate blitz_paint 

Paint a blitz_dom::BaseDocument by pushing anyrender drawing commands into an impl anyrender::PaintScene.

Structs

SceneLayerCounts
How many layers one painted scene asked for, and what it got.

Enums

LayerSite
Where a layer came from.

Functions

latest_scene_layers
Read the layer counts of the last scene painted in this process.
paint_scene
Paint a blitz_dom::BaseDocument by pushing drawing commands into an impl anyrender::PaintScene.
paint_scene_at_time